@@ -57,10 +57,11 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
     ~QgsCoordinateReferenceSystem();
 
     /*!
-     * Constructs a CRS object from a Wkt string
-     * @param theWkt A String containing a valid Wkt def
+     * Constructs a CRS object from a string definition as defined in the createFromString
+     * member function (by default a WKT definition).
+     * @param theDefinition A String containing a coordinate reference system definition.
      */
-    explicit QgsCoordinateReferenceSystem( QString theWkt );
+    explicit QgsCoordinateReferenceSystem( QString theDefinition );
 
     /*! Use this constructor when you want to create a CRS object using
      *  a postgis SRID, an EpsgCrsId id or a QGIS CRS_ID.
@@ -79,16 +80,14 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
 
     // Misc helper functions -----------------------
 
-    void createFromId( const long theId, CrsType theType = PostgisCrsId );
+    bool createFromId( const long theId, CrsType theType = PostgisCrsId );
 
     /**
      * \brief Set up this CRS from the given OGC CRS
      *
      * Sets this CRS to the given OGC WMS-format Coordinate Reference Systems.
      *
-     * \note This function only deals with EpsgCrsId labels only at this time.
-     *
-     * \retval false if not given an EpsgCrsId label
+     * \retval false if not given an valid label
      */
     bool createFromOgcWmsCrs( QString theCrs );
 
@@ -108,7 +107,7 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
      * @note Any members will be overwritten during this process.
      * @note SRID and EpsgCrsId may be blank if no match can be found on srs db.
      * @param theWkt The Wkt for the desired spatial reference system.
-     * @return bool TRUE if sucess else false
+     * @return bool TRUE if success else false
      */
     bool createFromWkt( const QString theWkt );
 
@@ -117,9 +116,10 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
      * and then the users ~/.qgis/qgis.db database will be checked for a match.
      * @note Any members will be overwritten during this process.
      * @param theEpsg The EpsgCrsId for the desired spatial reference system.
-     * @return bool TRUE if sucess else false
+     * @return bool TRUE if success else false
+     * @deprecated use createFromOgcWmsCrs()
      */
-    bool createFromEpsg( const long theEpsg );
+    Q_DECL_DEPRECATED bool createFromEpsg( const long theEpsg );
 
     /*! Set up this srs by fetching the appropriate information from the
      * sqlite backend. If the srsid is < 100000, only the system srs.db
@@ -127,7 +127,7 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
      * the ~/.qgis/qgis.db
      * @note Any members will be overwritten during this process.
      * @param theSrsId The QGIS SrsId for the desired spatial reference system.
-     * @return bool TRUE if sucess else false
+     * @return bool TRUE if success else false
      */
     bool createFromSrsId( const long theSrsId );
 
@@ -158,10 +158,19 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
      *    for this srs.
      *
      * @param theProjString A proj4 format string
-     * @return bool TRUE if sucess else false
+     * @return bool TRUE if success else false
      */
     bool createFromProj4( const QString theProjString );
 
+    /*! Set up this srs from a string definition, by default a WKT definition.  Otherwise
+     * the string defines a authority, followed by a colon, followed by the definition.
+     * The authority can be one of "epsg", "postgis", "internal" for integer definitions,
+     * and "wkt" or "proj4" for string definitions.  The implementation of each authority
+     * uses the corresponding createFrom... function.
+     * @param theDefinition A String containing a coordinate reference system definition.
+     */
+    bool createFromString( const QString theDefinition );
+
     /*! Find out whether this CRS is correctly initialised and usable */
     bool isValid() const;
 
@@ -252,8 +261,9 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
 
     /*! Get the EpsgCrsId identifier for this srs
      * @return  long theEpsg the EPSG identifier for this srs (defaults to 0)
+     * @deprecated there are other authorities - use authid()
      */
-    long epsg() const;
+    Q_DECL_DEPRECATED long epsg() const;
 
     /*! Get the authority identifier for this srs
      * @return  QString the Authority identifier for this srs
