@@ -12,7 +12,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsdistancearea.h 14191 2010-09-04 13:08:17Z mhugent $ */
+/* $Id$ */
 
 #ifndef QGSDISTANCEAREA_H
 #define QGSDISTANCEAREA_H
@@ -51,7 +51,10 @@ class CORE_EXPORT QgsDistanceArea
     void setSourceCrs( long srsid );
 
     //! sets source spatial reference system (by EpsgCrsId)
-    void setSourceEpsgCrsId( long epsgId );
+    Q_DECL_DEPRECATED void setSourceEpsgCrsId( long epsgId );
+
+    //! sets source spatial reference system by authid
+    void setSourceAuthId( QString authid );
 
     //! returns source spatial reference system
     long sourceCrs() { return mSourceRefSys; }
@@ -74,8 +77,12 @@ class CORE_EXPORT QgsDistanceArea
     //! general measurement (line distance or polygon area)
     double measure( QgsGeometry* geometry );
 
-    //! measures line with more segments
+    //! measures perimeter of polygon
+    double measurePerimeter( QgsGeometry* geometry );
+
+    //! measures line
     double measureLine( const QList<QgsPoint>& points );
+
     //! measures line with one segment
     double measureLine( const QgsPoint& p1, const QgsPoint& p2 );
 
@@ -88,11 +95,10 @@ class CORE_EXPORT QgsDistanceArea
     static QString textUnit( double value, int decimals, QGis::UnitType u, bool isArea, bool keepBaseUnit = false );
 
   protected:
-
     //! measures line distance, line points are extracted from WKB
     unsigned char* measureLine( unsigned char* feature, double* area, bool hasZptr = false );
-    //! measures polygon area, vertices are extracted from WKB
-    unsigned char* measurePolygon( unsigned char* feature, double* area, bool hasZptr = false );
+    //! measures polygon area and perimeter, vertices are extracted from WKB
+    unsigned char* measurePolygon( unsigned char* feature, double* area, double* perimeter, bool hasZptr = false );
 
     /**
       calculates distance from two points on ellipsoid
