@@ -13,7 +13,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgslegendinterface.h 14394 2010-10-18 00:13:51Z jef $ */
+/* $Id$ */
 
 #ifndef QGSLEGENDINTERFACE_H
 #define QGSLEGENDINTERFACE_H
@@ -23,6 +23,7 @@
 #include <QStringList>
 
 class QgsMapLayer;
+class QTreeWidgetItem;
 
 //Information about relationship between groups and layers
 //key: group name (or null strings for single layers without groups)
@@ -80,7 +81,12 @@ class GUI_EXPORT QgsLegendInterface : public QObject
   public slots:
 
     //! Add a new group
-    virtual int addGroup( QString name, bool expand = true ) = 0;
+    //! a parent group can be given to nest the new group in it
+    virtual int addGroup( QString name, bool expand = true, QTreeWidgetItem* parent = 0 ) = 0;
+
+    //! Add a new group
+    //! a parent group index has to be given to nest the new group in it
+    virtual int addGroup( QString name, bool expand, int parentIndex ) = 0;
 
     //! Remove group on index
     virtual void removeGroup( int groupIndex ) = 0;
