@@ -14,17 +14,18 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsmaplayer.h 14374 2010-10-13 19:40:16Z timlinux $ */
+/* $Id$ */
 
 #ifndef QGSMAPLAYER_H
 #define QGSMAPLAYER_H
 
-
+#include <QDateTime>
 #include <QObject>
 #include <QUndoStack>
 #include <QVariant>
 #include <QImage>
 
+#include "qgis.h"
 #include "qgsrectangle.h"
 
 class QgsRenderContext;
@@ -67,8 +68,15 @@ class CORE_EXPORT QgsMapLayer : public QObject
      */
     QgsMapLayer::LayerType type() const;
 
-    /** Get this layer's unique ID, this ID is used to access this layer from map layer registry */
-    QString getLayerID() const;
+    /** Get this layer's unique ID, this ID is used to access this layer from map layer registry
+     * @note added in 1.7
+     **/
+    QString id() const;
+
+    /** Get this layer's unique ID, this ID is used to access this layer from map layer registry
+     * @deprecated use id()
+     **/
+    Q_DECL_DEPRECATED QString getLayerID() const { return id(); }
 
     /** Set the display name of the layer
      * @param name New name for the layer
@@ -87,7 +95,7 @@ class CORE_EXPORT QgsMapLayer : public QObject
     /** This is the method that does the actual work of
      * drawing the layer onto a paint device.
      * @param rendererContext describes the extents,
-     * resolution etc. that should be used when rendering the
+     * resolumon etc. that should be used when rendering the
      * layer.
      */
     virtual bool draw( QgsRenderContext& rendererContext );
@@ -213,10 +221,10 @@ class CORE_EXPORT QgsMapLayer : public QObject
 
     /** Returns layer's spatial reference system
     @note This method is here for API compatibility
-    and will be deprecited in 2.0
-    @see crs()
+    and will be deprecated in 2.0
+    @deprecated use crs()
     */
-    const QgsCoordinateReferenceSystem& srs();
+    Q_DECL_DEPRECATED const QgsCoordinateReferenceSystem& srs();
 
     /** Sets layer's spatial reference system
     @note emitSignal added in 1.4 */
@@ -324,6 +332,9 @@ class CORE_EXPORT QgsMapLayer : public QObject
      * added in 1.5 */
     void clearCacheImage();
 
+    /** Time stamp of data source in the moment when data/metadata were loaded by provider */
+    virtual QDateTime timestamp() const { return QDateTime() ; }
+
   signals:
 
     /** Emit a signal to notify of a progress event */
@@ -373,11 +384,13 @@ class CORE_EXPORT QgsMapLayer : public QObject
     virtual bool writeXml( QDomNode & layer_node, QDomDocument & document );
 
 
-    /** Read custom properties from project file. Added in v1.4 */
-    void readCustomProperties( QDomNode & layerNode );
+    /** Read custom properties from project file. Added in v1.4
+      @param layerNode note to read from
+      @param keyStartsWith reads only properties starting with the specified string (or all if the string is empty)*/
+    void readCustomProperties( const QDomNode& layerNode, const QString& keyStartsWith = "" );
 
     /** Write custom properties to project file. Added in v1.4 */
-    void writeCustomProperties( QDomNode & layerNode, QDomDocument & doc );
+    void writeCustomProperties( QDomNode & layerNode, QDomDocument & doc ) const;
 
     /** debugging member - invoked when a connect() is made to this object */
     void connectNotify( const char * signal );
