@@ -12,7 +12,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsrubberband.h 14319 2010-09-30 22:53:18Z jef $ */
+/* $Id$ */
 #ifndef QGSRUBBERBAND_H
 #define QGSRUBBERBAND_H
 
@@ -61,6 +61,11 @@ class GUI_EXPORT QgsRubberBand: public QgsMapCanvasItem
     */
     void setToGeometry( QgsGeometry* geom, QgsVectorLayer* layer );
 
+    /**Sets this rubber band to a map canvas rectangle
+      @param rect rectangle in canvas coordinates
+      @note added in version 1.7*/
+    void setToCanvasRectangle( const QRect& rect );
+
     /**Add the geometry of an existing feature to a rubberband
      This is useful for multi feature highlighting.
     @param geom the geometry object
