@@ -145,6 +145,7 @@ class GUI_EXPORT QgsMarkerLineSymbolLayerV2Widget : public QgsSymbolLayerV2Widge
     void setMarker();
     void setRotate();
     void setOffset();
+    void setPlacement();
 
   protected:
 
@@ -208,6 +209,7 @@ class GUI_EXPORT QgsLineDecorationSymbolLayerV2Widget : public QgsSymbolLayerV2W
 
   public slots:
     void colorChanged();
+    void penWidthChanged();
 
   protected:
     QgsLineDecorationSymbolLayerV2* mLayer;
@@ -245,6 +247,7 @@ class GUI_EXPORT QgsSVGFillSymbolLayerWidget : public QgsSymbolLayerV2Widget, pr
     void on_mSVGLineEdit_textChanged( const QString & text );
     void setFile( const QModelIndex& item );
     void on_mChangeOutlinePushButton_clicked();
+    void on_mRotationSpinBox_valueChanged( double d );
 };
 
 //////////
@@ -274,11 +277,41 @@ class GUI_EXPORT QgsFontMarkerSymbolLayerV2Widget : public QgsSymbolLayerV2Widge
     void setSize( double size );
     void setAngle( double angle );
     void setCharacter( const QChar& chr );
+    void setOffset();
 
   protected:
     QgsFontMarkerSymbolLayerV2* mLayer;
     CharacterWidget* widgetChar;
 };
 
+//////////
+
+
+#include "ui_widget_centroidfill.h"
+
+class QgsCentroidFillSymbolLayerV2;
+
+class GUI_EXPORT QgsCentroidFillSymbolLayerV2Widget : public QgsSymbolLayerV2Widget, private Ui::WidgetCentroidFill
+{
+    Q_OBJECT
+
+  public:
+    QgsCentroidFillSymbolLayerV2Widget( QWidget* parent = NULL );
+
+    static QgsSymbolLayerV2Widget* create() { return new QgsCentroidFillSymbolLayerV2Widget(); }
+
+    // from base class
+    virtual void setSymbolLayer( QgsSymbolLayerV2* layer );
+    virtual QgsSymbolLayerV2* symbolLayer();
+
+  public slots:
+    void setMarker();
+
+  protected:
+    void updateMarker();
+
+    QgsCentroidFillSymbolLayerV2* mLayer;
+};
+
 
 #endif
