@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsvectorlayer.h 14455 2010-10-30 14:27:23Z jef $ */
+/* $Id$ */
 
 #ifndef QGSVECTORLAYER_H
 #define QGSVECTORLAYER_H
@@ -45,15 +45,41 @@ class QgsUndoCommand;
 class QgsVectorDataProvider;
 class QgsVectorOverlay;
 class QgsSingleSymbolRendererV2;
-
 class QgsRectangle;
-
+class QgsVectorLayerJoinBuffer;
 class QgsFeatureRendererV2;
+class QgsDiagramRendererV2;
+struct QgsDiagramLayerSettings;
 
 typedef QList<int> QgsAttributeList;
 typedef QSet<int> QgsFeatureIds;
 typedef QSet<int> QgsAttributeIds;
 
+/** @note added in 1.7 */
+struct CORE_EXPORT QgsVectorJoinInfo
+{
+  /**Join field in the target layer*/
+  int targetField;
+  /**Source layer*/
+  QString joinLayerId;
+  /**Join field in the source layer*/
+  int joinField;
+  /**True if the join is cached in virtual memory*/
+  bool memoryCache;
+  /**Cache for joined attributes to provide fast lookup (size is 0 if no memory caching)*/
+  QHash< QString, QgsAttributeMap> cachedAttributes;
+};
+
+/** Join information prepared for fast attribute id mapping in QgsVectorLayerJoinBuffer::updateFeatureAttributes().
+  Created in the select() method of QgsVectorLayerJoinBuffer for the joins that contain fetched attributes
+ @note added in 1.7
+*/
+struct CORE_EXPORT QgsFetchJoinInfo
+{
+  const QgsVectorJoinInfo* joinInfo;
+  QgsAttributeList attributes; //attributes to fetch
+  int indexOffset; //index offset between this layer and join layer
+};
 
 /** \ingroup core
  * Vector layer backed by a data source provider.
@@ -127,6 +153,18 @@ class CORE_EXPORT QgsVectorLayer : public QgsMapLayer
     /** Setup the coordinate system tranformation for the layer */
     void setCoordinateSystem();
 
+    /** Joins another vector layer to this layer
+      @param joinInfo join object containing join layer id, target and source field
+      @note added in 1.7 */
+    void addJoin( QgsVectorJoinInfo joinInfo );
+
+    /** Removes  a vector layer join
+      @note added in 1.7 */
+    void removeJoin( const QString& joinLayerId );
+
+    /** @note added in 1.7 */
+    const QList< QgsVectorJoinInfo >& vectorJoins() const;
+
     /** Get the label object associated with this layer */
     QgsLabel *label();
 
@@ -170,11 +208,18 @@ class CORE_EXPORT QgsVectorLayer : public QgsMapLayer
     /** Sets the renderer. If a renderer is already present, it is deleted */
     void setRenderer( QgsRenderer * r );
 
+    /** Sets diagram rendering object (takes ownership) */
+    void setDiagramRenderer( QgsDiagramRendererV2* r );
+    const QgsDiagramRendererV2* diagramRenderer() const { return mDiagramRenderer; }
+
+    void setDiagramLayerSettings( const QgsDiagramLayerSettings& s );
+    const QgsDiagramLayerSettings *diagramLayerSettings() const { return mDiagramLayerSettings; }
+
     /** Return renderer V2.
      * @note added in 1.4 */
     QgsFeatureRendererV2* rendererV2();
     /** Set renderer V2.
-     * @note ddded in 1.4
+     * @note added in 1.4
      */
     void setRendererV2( QgsFeatureRendererV2* r );
     /** Return whether using renderer V2.
@@ -199,6 +244,10 @@ class CORE_EXPORT QgsVectorLayer : public QgsMapLayer
     /** Returns point, line or polygon */
     QGis::GeometryType geometryType() const;
 
+    /** Returns true if this is a geometry layer and false in case of NoGeometry (table only) or UnknownGeometry
+      @note added in 1.7*/
+    bool hasGeometryType() const;
+
     /**Returns the WKBType or WKBUnknown in case of error*/
     QGis::WkbType wkbType() const;
 
@@ -352,11 +401,12 @@ class CORE_EXPORT QgsVectorLayer : public QgsMapLayer
     @return 0 in case of success*/
     int removePolygonIntersections( QgsGeometry* geom );
 
-    /**Adds topological points for every vertex of the
-     geometry
+    /** Adds topological points for every vertex of the geometry.
     @param geom the geometry where each vertex is added to segments of other features
-    Note: geom is not going to be modified by the function
-    @return 0 in case of success*/
+    @note geom is not going to be modified by the function
+    @return 0 in case of success
+    @see addTopologicalPoints
+    */
     int addTopologicalPoints( QgsGeometry* geom );
 
     /**Adds a vertex to segments which intersect point p but don't
@@ -456,8 +506,8 @@ class CORE_EXPORT QgsVectorLayer : public QgsMapLayer
 
     /** add an attribute field (but does not commit it)
       returns true if the field was added
-      @note deprecated */
-    bool addAttribute( QString name, QString type );
+      @deprecated */
+    Q_DECL_DEPRECATED bool addAttribute( QString name, QString type );
 
     /**Sets an alias (a display name) for attributes to display in dialogs
       @note added in version 1.2*/
@@ -594,6 +644,29 @@ class CORE_EXPORT QgsVectorLayer : public QgsMapLayer
       @note public and static from version 1.4 */
     static void drawVertexMarker( double x, double y, QPainter& p, QgsVectorLayer::VertexMarkerType type, int vertexSize );
 
+    /** Assembles mUpdatedFields considering provider fields, joined fields and added fields
+     @note added in 1.7 */
+    void updateFieldMap();
+
+    /** Caches joined attributes if required (and not already done)
+      @note added in 1.7 */
+    void createJoinCaches();
+
+    /**Returns unique values for column
+      @param index column index for attribute
+      @param uniqueValues out: result list
+      @param limit maximum number of values to return (-1 if unlimited)
+      @note this method was added in version 1.7*/
+    void uniqueValues( int index, QList<QVariant> &uniqueValues, int limit = -1 );
+
+    /**Returns minimum value for an attribute column or invalid variant in case of error
+         @note added in 1.7*/
+    QVariant minimumValue( int index );
+
+    /**Returns maximum value for an attribute column or invalid variant in case of error
+      @note added in 1.7*/
+    QVariant maximumValue( int index );
+
   public slots:
     /** Select feature by its ID, optionally emit signal selectionChanged() */
     void select( int featureId, bool emitSignal = true );
@@ -611,6 +684,10 @@ class CORE_EXPORT QgsVectorLayer : public QgsMapLayer
      */
     virtual void updateExtents();
 
+    /** Check if there is a join with a layer that will be removed
+      @note added in 1.7 */
+    void checkJoinLayerRemove( QString theLayerId );
+
   signals:
 
     /** This signal is emited when selection was changed */
@@ -623,12 +700,14 @@ class CORE_EXPORT QgsVectorLayer : public QgsMapLayer
     void editingStopped();
     void attributeAdded( int idx );
     void attributeDeleted( int idx );
+    void featureAdded( int fid );  // added in 1.7
     void featureDeleted( int fid );
     void layerDeleted();
 
     void attributeValueChanged( int fid, int idx, const QVariant & );
 
-    /** Signals emitted after committing changes */
+    /** Signals emitted after committing changes
+      \note added in v1.6 */
     void committedAttributesDeleted( const QString& layerId, const QgsAttributeIds& deletedAttributeIds );
     void committedAttributesAdded( const QString& layerId, const QList<QgsField>& addedAttributes );
     void committedFeaturesAdded( const QString& layerId, const QgsFeatureList& addedFeatures );
@@ -699,9 +778,19 @@ class CORE_EXPORT QgsVectorLayer : public QgsMapLayer
     /**Reads vertex marker size from settings*/
     static int currentVertexMarkerSize();
 
-    /**Update feature with uncommited attribute updates*/
+    /**Update feature with uncommited attribute updates and joined attributes*/
     void updateFeatureAttributes( QgsFeature &f, bool all = false );
 
+    /**Adds joined attributes to a feature
+      @param f the feature to add the attributes
+      @param joinInfo vector join
+      @param joinFieldName name of the (source) join Field
+      @param joinValue lookup value for join
+      @param attributes (join layer) attribute indices to add
+      @param attributeIndexOffset index offset to get from join layer attribute index to layer index*/
+    void addJoinedFeatureAttributes( QgsFeature& f, const QgsVectorJoinInfo& joinInfo, const QString& joinFieldName, const QVariant& joinValue,
+                                     const QgsAttributeList& attributes, int attributeIndexOffset );
+
     /**Update feature with uncommited geometry updates*/
     void updateFeatureGeometry( QgsFeature &f );
 
@@ -720,6 +809,15 @@ class CORE_EXPORT QgsVectorLayer : public QgsMapLayer
     /** Stop version 2 renderer and selected renderer (if required) */
     void stopRendererV2( QgsRenderContext& rendererContext, QgsSingleSymbolRendererV2* selRenderer );
 
+    /**Updates an index in an attribute map to a new value (usually necessary because of a join operation)*/
+    void updateAttributeMapIndex( QgsAttributeMap& map, int oldIndex, int newIndex ) const;
+
+    /**Registers label and diagram layer
+      @param rendererContext render context
+      @param attributes attributes needed for labeling and diagrams will be added to the list
+      @param labeling out: true if there will be labeling (ng) for this layer*/
+    void prepareLabelingAndDiagrams( QgsRenderContext& rendererContext, QgsAttributeList& attributes, bool& labeling );
+
   private:                       // Private attributes
 
     /** Update threshold for drawing features as they are read. A value of zero indicates
@@ -786,8 +884,8 @@ class CORE_EXPORT QgsVectorLayer : public QgsMapLayer
     /** field map to commit */
     QgsFieldMap mUpdatedFields;
 
-    /**Map that stores the aliases for attributes. Key is the attribute index and value the alias for that attribute*/
-    QMap<int, QString> mAttributeAliasMap;
+    /**Map that stores the aliases for attributes. Key is the attribute name and value the alias for that attribute*/
+    QMap< QString, QString > mAttributeAliasMap;
 
     /** max field index */
     int mMaxUpdatedIndex;
@@ -844,6 +942,15 @@ class CORE_EXPORT QgsVectorLayer : public QgsMapLayer
     QSet<int> mFetchConsidered;
     QgsGeometryMap::iterator mFetchChangedGeomIt;
     QgsFeatureList::iterator mFetchAddedFeaturesIt;
+
+    //stores information about joined layers
+    QgsVectorLayerJoinBuffer* mJoinBuffer;
+
+    //diagram rendering object. 0 if diagram drawing is disabled
+    QgsDiagramRendererV2* mDiagramRenderer;
+
+    //stores infos about diagram placement (placement type, priority, position distance)
+    QgsDiagramLayerSettings *mDiagramLayerSettings;
 };
 
 #endif
