@@ -1,4 +1,33 @@
 # -*- coding: utf-8 -*-
+#-----------------------------------------------------------
+#
+# fTools
+# Copyright (C) 2008-2011  Carson Farmer
+# EMAIL: carson.farmer (at) gmail.com
+# WEB  : http://www.ftools.ca/fTools.html
+#
+# A collection of data management and analysis tools for vector data
+#
+#-----------------------------------------------------------
+#
+# licensed under the terms of GNU GPL 2
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+#
+#---------------------------------------------------------------------
+
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 
@@ -64,9 +93,9 @@ class Dialog(QDialog, Ui_Dialog):
                     outProj = self.txtProjection.text()
                     srsDefine.createFromProj4(outProj)
                 else:
-                    destLayer = self.getVectorLayerByName(self.cmbLayer.currentText())
-                    srsDefine = destLayer.srs()
-                if srsDefine == vLayer.srs():
+                    destLayer = ftools_utils.getVectorLayerByName(self.cmbLayer.currentText())
+                    srsDefine = destLayer.crs()
+                if srsDefine == vLayer.crs():
                     responce = QMessageBox.question(self, self.tr("Define current projection"),
                     self.tr("Identical output spatial reference system chosen\n\nAre you sure you want to proceed?"),
                     QMessageBox.Yes, QMessageBox.No, QMessageBox.NoButton)
@@ -123,4 +152,4 @@ class Dialog(QDialog, Ui_Dialog):
                 self.txtProjection.clear()
                 self.txtProjection.insert(projString)
         else:
-            return
\ No newline at end of file
+            return
