@@ -175,13 +175,20 @@ class GeoprocessingDialog( QDialog, Ui_Dialog ):
       elif self.myFunction == 7: # Symetrical difference
         self.label_2.setText( self.tr( "Difference layer" ) )
         self.setWindowTitle( self.tr( "Symetrical difference" ) )
+        self.useSelectedA.hide()
+        self.useSelectedB.hide()
       elif self.myFunction == 8: # Clip
         self.label_2.setText( self.tr( "Clip layer" ) )
         self.setWindowTitle( self.tr( "Clip" ) )
       else: # Union
         self.label_2.setText( self.tr( "Union layer" ) )
         self.setWindowTitle( self.tr( "Union" ) )
+        self.useSelectedA.hide()
+        self.useSelectedB.hide()
     self.resize(381, 100)
+    self.populateLayers()
+
+  def populateLayers( self ):
     myListA = []
     myListB = []
     self.inShapeA.clear()
@@ -195,7 +202,6 @@ class GeoprocessingDialog( QDialog, Ui_Dialog ):
       myListB = ftools_utils.getLayerNames( [ QGis.Point, QGis.Line, QGis.Polygon ] )
     self.inShapeA.addItems( myListA )
     self.inShapeB.addItems( myListB )
-    return
 
 #1: Buffer
 #2: Convex Hull
@@ -257,6 +263,7 @@ class GeoprocessingDialog( QDialog, Ui_Dialog ):
     if addToTOC == QMessageBox.Yes:
       if not ftools_utils.addShapeToCanvas( unicode( self.shapefileName ) ):
           QMessageBox.warning( self, self.tr("Geoprocessing"), self.tr( "Error loading output shapefile:\n%1" ).arg( unicode( self.shapefileName ) ))
+      self.populateLayers()
 
   def runStatusFromThread( self, status ):
     self.progressBar.setValue( status )
@@ -1038,9 +1045,7 @@ class geoprocessingThread( QThread ):
                   int_geom = QgsGeometry( int_com.difference( int_sym ) )
                 try:
                   outFeat.setGeometry( int_geom )
-                  print outFeat.isValid()
                   outFeat.setAttributeMap( ftools_utils.combineVectorAttributes( atMapA, atMapB ) )
-                  print outFeat.isValid()
                   writer.addFeature( outFeat )
                 except:
                   FEATURE_EXCEPT = False
@@ -1049,7 +1054,6 @@ class geoprocessingThread( QThread ):
               GEOS_EXCEPT = False
               break
     del writer
-    print crs_match
     return GEOS_EXCEPT, FEATURE_EXCEPT, crs_match, None
 
   def union( self ):
@@ -1061,6 +1065,7 @@ class geoprocessingThread( QThread ):
     vproviderB = self.vlayerB.dataProvider()
     allAttrsB = vproviderB.attributeIndexes()
     vproviderB.select( allAttrsB )
+
     # check for crs compatibility
     crsA = vproviderA.crs()
     crsB = vproviderB.crs()
@@ -1068,26 +1073,32 @@ class geoprocessingThread( QThread ):
         crs_match = None
     else:
         crs_match = crsA == crsB
+
     fields = ftools_utils.combineVectorFields( self.vlayerA, self.vlayerB )
     longNames = ftools_utils.checkFieldNameLength( fields )
     if not longNames.isEmpty():
       message = QString( 'Following field names are longer than 10 characters:\n%1' ).arg( longNames.join( '\n' ) )
       return GEOS_EXCEPT, FEATURE_EXCEPT, crs_match, message
-    writer = QgsVectorFileWriter( self.myName, self.myEncoding,
-    fields, vproviderA.geometryType(), vproviderA.crs() )
+
+    writer = QgsVectorFileWriter( self.myName, self.myEncoding, fields,
+                                  vproviderA.geometryType(), vproviderA.crs() )
     if writer.hasError():
       return GEOS_EXCEPT, FEATURE_EXCEPT, crs_match, writer.errorMessage()
+
     inFeatA = QgsFeature()
     inFeatB = QgsFeature()
     outFeat = QgsFeature()
     indexA = ftools_utils.createIndex( vproviderB )
     indexB = ftools_utils.createIndex( vproviderA )
+
     nFeat = vproviderA.featureCount() * vproviderB.featureCount()
-    nElement = 0
     self.emit( SIGNAL( "runStatus(PyQt_PyObject)" ), 0)
     self.emit( SIGNAL( "runRange(PyQt_PyObject)" ), ( 0, nFeat ) )
+
     vproviderA.rewind()
     count = 0
+    nElement = 0
+
     while vproviderA.nextFeature( inFeatA ):
       self.emit( SIGNAL( "runStatus(PyQt_PyObject)" ), nElement )
       nElement += 1
@@ -1102,10 +1113,9 @@ class geoprocessingThread( QThread ):
           outFeat.setAttributeMap( atMapA )
           writer.addFeature( outFeat )
         except:
-          FEATURE_EXCEPT = False
-          # this really shouldn't happen, as we 
+          # this really shouldn't happen, as we
           # haven't edited the input geom at all
-          # continue
+          FEATURE_EXCEPT = False
       else:
         for id in intersects:
           count += 1
@@ -1116,12 +1126,14 @@ class geoprocessingThread( QThread ):
             if geom.intersects( tmpGeom ):
               found = True
               int_geom = geom.intersection( tmpGeom )
+
               if int_geom is None:
-                GEOS_EXCEPT = False
                 # There was a problem creating the intersection
+                GEOS_EXCEPT = False
                 int_geom = QgsGeometry()
               else:
                 int_geom = QgsGeometry(int_geom)
+
               if diff_geom.intersects( tmpGeom ):
                 diff_geom = diff_geom.difference( tmpGeom )
                 if diff_geom is None:
@@ -1129,8 +1141,9 @@ class geoprocessingThread( QThread ):
                   diff_geom = QgsGeometry()
                 else:
                   diff_geom = QgsGeometry(diff_geom)
+
               if int_geom.wkbType() == 0:
-              # intersection produced different geomety types
+                # intersection produced different geomety types
                 temp_list = int_geom.asGeometryCollection()
                 for i in temp_list:
                   if i.type() == geom.type():
@@ -1138,27 +1151,23 @@ class geoprocessingThread( QThread ):
               try:
                 outFeat.setGeometry( int_geom )
                 outFeat.setAttributeMap( ftools_utils.combineVectorAttributes( atMapA, atMapB ) )
-#                print int_geom.wkbType()
                 writer.addFeature( outFeat )
               except Exception, err:
-#                print str(err)
                 FEATURE_EXCEPT = False
-#            else:
-#              # this only happends if the bounding box 
-#              # intersects, but the geometry doesn't
-#              try:
-#                outFeat.setGeometry( geom )
-#                outFeat.setAttributeMap( atMapA )
-#                print geom.wkbType()
-#                writer.addFeature( outFeat )
-#              except:
-##                # also shoudn't ever happen
-#                FEATURE_EXCEPT = False
-#              pass
+            else:
+              # this only happends if the bounding box
+              # intersects, but the geometry doesn't
+              try:
+                outFeat.setGeometry( geom )
+                outFeat.setAttributeMap( atMapA )
+                writer.addFeature( outFeat )
+              except:
+                # also shoudn't ever happen
+                FEATURE_EXCEPT = False
           except Exception, err:
-#            print str(err)
             GEOS_EXCEPT = False
             found = False
+
         if found:
           try:
             if diff_geom.wkbType() == 0:
@@ -1168,14 +1177,13 @@ class geoprocessingThread( QThread ):
                     diff_geom = QgsGeometry( i )
             outFeat.setGeometry( diff_geom )
             outFeat.setAttributeMap( atMapA )
-#            print diff_geom.wkbType()
             writer.addFeature( outFeat )
           except Exception, err:
-#            print str(err)
             FEATURE_EXCEPT = False
-#            continue
+
     length = len( vproviderA.fields().values() )
     vproviderB.rewind()
+
     while vproviderB.nextFeature( inFeatA ):
       add = False
       geom = QgsGeometry( inFeatA.geometry() )
@@ -1183,36 +1191,42 @@ class geoprocessingThread( QThread ):
       atMap = inFeatA.attributeMap().values()
       atMap = dict( zip( range( length, length + len( atMap ) ), atMap ) )
       intersects = indexB.intersects( geom.boundingBox() )
+
       if len(intersects) < 1:
         try:
           outFeat.setGeometry( geom )
           outFeat.setAttributeMap( atMap )
           writer.addFeature( outFeat )
         except Exception, err:
-#          print str(err)
           FEATURE_EXCEPT = False
       else:
         for id in intersects:
           vproviderA.featureAtId( int( id ), inFeatB , True, allAttrsA )
           atMapB = inFeatB.attributeMap()
           tmpGeom = QgsGeometry( inFeatB.geometry() )
+
           try:
             if diff_geom.intersects( tmpGeom ):
               add = True
               diff_geom = QgsGeometry( diff_geom.difference( tmpGeom ) )
+            else:
+              # this only happends if the bounding box
+              # intersects, but the geometry doesn't
+              outFeat.setGeometry( diff_geom )
+              outFeat.setAttributeMap( atMap )
+              writer.addFeature( outFeat )
           except Exception, err:
-#            print str(err)
             add = False
             GEOS_EXCEPT = False
+
         if add:
           try:
             outFeat.setGeometry( diff_geom )
             outFeat.setAttributeMap( atMapB )
             writer.addFeature( outFeat )
           except Exception, err:
-#            print str(err)
             FEATURE_EXCEPT = False
-#            continue
+
       self.emit( SIGNAL( "runStatus(PyQt_PyObject)" ),  nElement )
       nElement += 1
     del writer
