@@ -203,7 +203,7 @@ def getVectorLayerByName( myName ):
                 return layer
             else:
                 return None
-    
+
 # Return QgsMapLayer from a layer name ( as string )
 def getMapLayerByName( myName ):
     layermap = QgsMapLayerRegistry.instance().mapLayers()
@@ -249,15 +249,7 @@ def addShapeToCanvas( shapefile_path ):
 
 # Return all unique values in field based on field index
 def getUniqueValues( provider, index ):
-    allAttrs = provider.attributeIndexes()
-    provider.select( allAttrs )
-    f = QgsFeature()
-    values = []
-    check = []
-    while provider.nextFeature( f ):
-        if not f.attributeMap()[ index ].toString() in check:
-            values.append( f.attributeMap()[ index ] )
-            check.append( f.attributeMap()[ index ].toString() )
+    values = provider.uniqueValues( index )
     return values
 
 # Generate a save file dialog with a dropdown box for choosing encoding style
@@ -332,3 +324,23 @@ def getUniqueValuesCount( vlayer, fieldIndex, useSelection ):
                 values.append( feat.attributeMap()[ fieldIndex ].toString() )
                 count += 1
     return count
+
+def getShapesByGeometryType( baseDir, inShapes, geomType ):
+  outShapes = QStringList()
+  for fileName in inShapes:
+    layerPath = QFileInfo( baseDir + "/" + fileName ).absoluteFilePath()
+    vLayer = QgsVectorLayer( layerPath, QFileInfo( layerPath ).baseName(), "ogr" )
+    if not vLayer.isValid():
+      continue
+    layerGeometry = vLayer.geometryType()
+    if layerGeometry == QGis.Polygon and geomType == 0:
+      outShapes << fileName
+    elif layerGeometry == QGis.Line and geomType == 1:
+      outShapes << fileName
+    elif layerGeometry == QGis.Point and geomType == 2:
+      outShapes << fileName
+
+  if outShapes.count() == 0:
+    return None
+
+  return outShapes
